Introduction
============

Base mail content class (paper document, email) for document management system.

This product is an extension for `collective.dms.basecontent <https://pypi.org/project/collective.dms.basecontent>`_
.

Features
--------

- Add dmsincomingmail type : content type to handle metadata of an incoming mail
- Add dmsoutgoingmail type : content type to handle metadata of an outgoing mail

Handle a reply form to create an outgoing mail from an incoming mail.

Tests
=====

This add-on is tested using Travis CI. The current status of the add-on is :

.. image:: https://secure.travis-ci.org/collective/collective.dms.mailcontent.png
    :target: http://travis-ci.org/collective/collective.dms.mailcontent
